@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015 Stuart Howarth <showarth@marxoft.co.uk>
+ * Copyright (C) 2016 Stuart Howarth <showarth@marxoft.co.uk>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3 as
@@ -67,7 +67,9 @@ public:
 #endif
 
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    
+#ifdef WIDGETS_UI
+    int columnCount(const QModelIndex &parent = QModelIndex()) const;
+#endif
     QVariant data(const QModelIndex &index, int role) const;
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
     
@@ -76,6 +78,8 @@ public:
     
     Q_INVOKABLE Subscription* get(int row) const;
     
+    QModelIndexList match(const QModelIndex &start, int role, const QVariant &value, int hits = 1,
+                          Qt::MatchFlags flags = Qt::MatchFlags(Qt::MatchStartsWith | Qt::MatchWrap)) const;
     Q_INVOKABLE int match(const QByteArray &role, const QVariant &value) const;
 
 public Q_SLOTS:
