@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015 Stuart Howarth <showarth@marxoft.co.uk>
+ * Copyright (C) 2016 Stuart Howarth <showarth@marxoft.co.uk>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3 as
@@ -28,11 +28,12 @@
 #include <QProcess>
 #include <QImage>
 #include <QDir>
+#include <QDBusConnection>
 #ifdef CUTENEWS_DEBUG
 #include <QDebug>
 #endif
 
-static const int REQUEST_ID = 1001;
+static const int REQUEST_ID = Utils::createId();
 #ifdef USE_FAVICONS
 static const QString FAVICONS_URL("http://www.google.com/s2/favicons?domain=");
 #endif
@@ -49,6 +50,10 @@ Subscriptions::Subscriptions() :
     m_total(0)
 {
     connect(Database::instance(), SIGNAL(subscriptionsAdded(int)), this, SLOT(onSubscriptionsAdded(int)));
+    
+    QDBusConnection connection = QDBusConnection::sessionBus();
+    connection.registerService("org.marxoft.cutenews.subscriptions");
+    connection.registerObject("/org/marxoft/cutenews/subscriptions", this, QDBusConnection::ExportScriptableSlots);
 }
 
 Subscriptions::~Subscriptions() {
@@ -189,7 +194,7 @@ void Subscriptions::update(int id) {
     }
 }
 
-void Subscriptions::updateAll() {
+bool Subscriptions::updateAll() {
 #ifdef CUTENEWS_DEBUG
     qDebug() << "Subscriptions::updateAll";
 #endif
@@ -197,7 +202,10 @@ void Subscriptions::updateAll() {
         connect(Database::instance(), SIGNAL(queryReady(QSqlQuery, int)),
                 this, SLOT(onSubscriptionIdsFetched(QSqlQuery, int)));
         Database::execQuery(QString("SELECT id FROM subscriptions"), REQUEST_ID);
+        return true;
     }
+    
+    return false;
 }
 
 void Subscriptions::next() {
@@ -312,21 +320,21 @@ void Subscriptions::parseXml(const QByteArray &xml) {
     
     if (parser.date() <= lastUpdated) {
         Database::updateSubscription(subscriptionId, subscription);
+        
+        if (Database::subscriptionIconPath(m_query).isEmpty()) {
+            if (!channelIconUrl.isEmpty()) {
+                downloadIcon(channelIconUrl);
+                return;
+            }
 #ifdef USE_FAVICONS
-        if ((!channelUrl.isEmpty()) && (Database::subscriptionIconPath(m_query).isEmpty())) {
-            downloadIcon(FAVICONS_URL + channelUrl.host());
-        }
-        else {
-            next();
-        }
-#else
-        if ((!channelIconUrl.isEmpty()) && (Database::subscriptionIconPath(m_query).isEmpty())) {
-            downloadIcon(channelIconUrl);
-        }
-        else {
-            next();
-        }
+            if (!channelUrl.isEmpty()) {
+                downloadIcon(FAVICONS_URL + channelUrl.host());
+                return;
+            }
 #endif
+        }
+    
+        next();
         return;
     }
         
@@ -362,21 +370,21 @@ void Subscriptions::parseXml(const QByteArray &xml) {
                           << favourites << reads << subscriptionIds << titles << urls,
                           subscriptionId);
     Database::updateSubscription(subscriptionId, subscription);
+    
+    if (Database::subscriptionIconPath(m_query).isEmpty()) {
+        if (!channelIconUrl.isEmpty()) {
+            downloadIcon(channelIconUrl);
+            return;
+        }
 #ifdef USE_FAVICONS
-    if ((!channelUrl.isEmpty()) && (Database::subscriptionIconPath(m_query).isEmpty())) {
-        downloadIcon(FAVICONS_URL + channelUrl.host());
-    }
-    else {
-        next();
-    }
-#else
-    if ((!channelIconUrl.isEmpty()) && (Database::subscriptionIconPath(m_query).isEmpty())) {
-        downloadIcon(channelIconUrl);
-    }
-    else {
-        next();
-    }
+        if (!channelUrl.isEmpty()) {
+            downloadIcon(FAVICONS_URL + channelUrl.host());
+            return;
+        }
 #endif
+    }
+    
+    next();
 }
 
 void Subscriptions::downloadIcon(const QUrl &url) {
@@ -434,9 +442,7 @@ void Subscriptions::onIconDownloadStatusChanged() {
             }
             
             if (QDir().mkpath(ICON_PATH)) {
-                const QString ext = m_iconDownload->url().path().section('.', -1);
-                const QString fileName = QString("%1%2.%3").arg(ICON_PATH).arg(Database::subscriptionId(m_query))
-                                                           .arg(ext.isEmpty() ? QString("png") : ext);
+                const QString fileName = QString("%1%2.png").arg(ICON_PATH).arg(Database::subscriptionId(m_query));
             
                 if ((!image.isNull()) && (image.save(fileName))) {
                     QVariantMap subscription;
